@@ -25,15 +25,6 @@ impl Simd<f32> for f32x16 {
 
     const LEN: usize = 16;
 
-    #[inline]
-    fn load_wrap_unchecked(array: &[f32], idx: usize) -> f32x16 {
-        let mut temp = [0.0; 16];
-        for (i, t) in temp.iter_mut().enumerate() {
-            *t = unsafe { *array.get_unchecked((idx + i) % array.len()) };
-        }
-        f32x16::load(&temp, 0)
-    }
-
     #[inline]
     fn from_complex(value: Complex<f32>) -> f32x16 {
         f32x16::new(
@@ -175,33 +166,21 @@ impl Simd<f32> for f32x16 {
         unsafe { _mm512_sqrt_ps(squared_sum) }
     }
 
-    #[inline]
-    fn complex_abs_squared2(self) -> f32x16 {
-        self.complex_abs_squared()
-    }
-
-    #[inline]
-    fn complex_abs2(self) -> f32x16 {
-        self.complex_abs()
-    }
-
     #[inline]
     fn sqrt(self) -> f32x16 {
         unsafe { _mm512_sqrt_ps(self) }
     }
 
     #[inline]
-    fn store_half_unchecked(self, target: &mut [f32], index: usize) {
-        unsafe {
-            *target.get_unchecked_mut(index) = self.extract(0);
-            *target.get_unchecked_mut(index + 1) = self.extract(1);
-            *target.get_unchecked_mut(index + 2) = self.extract(2);
-            *target.get_unchecked_mut(index + 3) = self.extract(3);
-            *target.get_unchecked_mut(index + 4) = self.extract(4);
-            *target.get_unchecked_mut(index + 5) = self.extract(5);
-            *target.get_unchecked_mut(index + 6) = self.extract(6);
-            *target.get_unchecked_mut(index + 7) = self.extract(7);
-        }
+    fn store_half(self, target: &mut [f32], index: usize) {
+        target[index] = self.extract(0);
+        target[index + 1] = self.extract(1);
+        target[index + 2] = self.extract(2);
+        target[index + 3] = self.extract(3);
+        target[index + 4] = self.extract(4);
+        target[index + 5] = self.extract(5);
+        target[index + 6] = self.extract(6);
+        target[index + 7] = self.extract(7);
     }
 
     #[inline]
@@ -248,12 +227,12 @@ impl Simd<f32> for f32x16 {
 
     #[inline]
     fn max(self, other: Self) -> Self {
-        unsafe { _mm512_max_ps(self, other) }
+        self.max(other)
     }
 
     #[inline]
     fn min(self, other: Self) -> Self {
-        unsafe { _mm512_min_ps(self, other) }
+        self.min(other)
     }
 }
 
@@ -271,15 +250,6 @@ impl Simd<f64> for f64x8 {
 
     const LEN: usize = 8;
 
-    #[inline]
-    fn load_wrap_unchecked(array: &[f64], idx: usize) -> f64x8 {
-        let mut temp = [0.0; 8];
-        for (i, t) in temp.iter_mut().enumerate() {
-            *t = unsafe { *array.get_unchecked((idx + i) % array.len()) };
-        }
-        f64x8::load(&temp, 0)
-    }
-
     #[inline]
     fn from_complex(value: Complex<f64>) -> f64x8 {
         f64x8::new(value.re, value.im, value.re, value.im)
@@ -388,31 +358,17 @@ impl Simd<f64> for f64x8 {
         unsafe { _mm512_sqrt_pd(squared_sum) }
     }
 
-    #[inline]
-    fn complex_abs_squared2(self) -> f64x8 {
-        self.complex_abs_squared()
-    }
-
-    #[inline]
-    fn complex_abs2(self) -> f64x8 {
-        self.complex_abs()
-    }
-
     #[inline]
     fn sqrt(self) -> f64x8 {
         unsafe { _mm512_sqrt_pd(self) }
     }
 
     #[inline]
-    fn store_half_unchecked(self, target: &mut [f64], index: usize) {
-        let mut temp = [0.0; 8];
-        self.store(&mut temp, 0);
-        unsafe {
-            *target.get_unchecked_mut(index) = temp[0];
-            *target.get_unchecked_mut(index + 1) = temp[2];
-            *target.get_unchecked_mut(index + 2) = temp[4];
-            *target.get_unchecked_mut(index + 3) = temp[6];
-        }
+    fn store_half(self, target: &mut [f64], index: usize) {
+        target[index] = self.extract(0);
+        target[index + 1] = self.extract(1);
+        target[index + 2] = self.extract(2);
+        target[index + 3] = self.extract(3);
     }
 
     #[inline]
@@ -437,12 +393,12 @@ impl Simd<f64> for f64x8 {
 
     #[inline]
     fn max(self, other: Self) -> Self {
-        unsafe { _mm512_max_pd(self, other) }
+        self.max(other)
     }
 
     #[inline]
     fn min(self, other: Self) -> Self {
-        unsafe { _mm512_min_pd(self, other) }
+        self.min(other)
     }
 }
 
